==> department-2.4.3.tgz: package/es/scenes/Auth/components/securedModalPage.js <==
function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { graphql } from 'react-apollo';
import { Loading } from '../../../components/Loading';
import { ModalRoutePage } from '../../../components/Modals';
import { checkPermissionQuery } from '../api';

function securedModalPage(props) {
  return function (WrappedComponent) {
    var SecuredPage = function SecuredPage(_ref) {
      var data = _ref.data,
          restProps = _objectWithoutProperties(_ref, ['data']);

      var loading = data.loading,
          error = data.error,
          checkPermission = data.checkPermission;


      if (loading) {
        return React.createElement(
          ModalRoutePage,
          null,
          React.createElement(Loading, null)
        );
      }

      if (!loading && !checkPermission) {
        return React.createElement(
          ModalRoutePage,
          null,
          React.createElement(
            'p',
            null,
            'Forbidden'
          )
        );
      }

      if (!loading && error) {
        return React.createElement(
          ModalRoutePage,
          null,
          React.createElement(
            'p',
            null,
            'Request error'
          )
        );
      }

      return React.createElement(WrappedComponent, restProps);
    };

    SecuredPage.propTypes = {
      data: PropTypes.object.isRequired
    };

    return graphql(checkPermissionQuery, {
      options: {
        variables: { permission: props.permission },
        fetchPolicy: 'network-only'
      }
    })(SecuredPage);
  };
}

export default securedModalPage;

==> department-2.5.0.tgz: package/es/scenes/Auth/components/securedModalPage.js <==
function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { graphql } from 'react-apollo';
import { Loading } from '../../../components/Loading';
import { ModalRoutePage } from '../../../components/Modals';
import { currentUserQuery } from '../api';
import { userHasPermission } from '../utilities';

function securedPage(options) {
  return function (WrappedComponent) {
    var SecuredPage = function SecuredPage(_ref) {
      var data = _ref.data,
          restProps = _objectWithoutProperties(_ref, ['data']);

      var loading = data.loading,
          error = data.error,
          currentUser = data.currentUser;


      if (loading) {
        return React.createElement(
          ModalRoutePage,
          null,
          React.createElement(Loading, null)
        );
      }

      if (!loading && error) {
        return React.createElement(
          ModalRoutePage,
          null,
          React.createElement(
            'p',
            null,
            'Request error'
          )
        );
      }

      if (!loading && !userHasPermission(currentUser, options.permission)) {
        return React.createElement(
          ModalRoutePage,
          null,
          React.createElement(
            'p',
            null,
            'Forbidden'
          )
        );
      }

      return React.createElement(WrappedComponent, restProps);
    };

    SecuredPage.propTypes = {
      data: PropTypes.object.isRequired
    };

    return graphql(currentUserQuery, {
      options: { fetchPolicy: 'cache-only' }
    })(SecuredPage);
  };
}

export default securedPage;
